@@ -54,9 +54,13 @@ class Script:
         return Script(self.commands + other.commands)
 
     @classmethod
-    def parse(cls, stream):
-        # get the length of the entire field
-        raw = read_varstr(stream)
+    def parse(cls, stream=None, raw=None):
+        if stream and raw:
+            raise ValueError("provide exactly one of stream/raw, not both")
+        if raw is None:
+            if stream is None:
+                raise ValueError("provide one of stream/raw")
+            raw = read_varstr(stream)
         length = len(raw)
         s = BytesIO(raw)
         # initialize the commands array
@@ -101,10 +105,16 @@ class Script:
                 commands.append(op_code)
         obj = cls(commands)
         if count != length:
+            # Would throw error, but Bitcoin Core will read the number of bytes that are there (not what was promised)
             print(f"mismatch between length and consumed bytes {count} vs {length}")
             obj.raw = raw
         return obj
 
+    @classmethod
+    def parse_hex(cls, hex_str):
+        """Helper method to make it easier to parse a hex string without converting to bytes"""
+        return cls.parse(raw=bytes.fromhex(hex_str))
+
     def raw_serialize(self):
         if self.raw:
             return self.raw
@@ -539,11 +549,6 @@ class P2TRScriptPubKey(ScriptPubKey):
         # convert to bech32 address using encode_bech32_checksum
         return encode_bech32_checksum(witness_program, network)
 
-    @classmethod
-    def from_address(cls, address):
-        _, _, point_raw = decode_bech32(address)
-        return cls(point_raw)
-
 
 class WitnessScript(Script):
     """Subclass that represents a WitnessScript for p2wsh"""
@@ -608,12 +613,17 @@ def address_to_script_pubkey(s):
         # p2sh
         h160 = decode_base58(s)
         return P2SHScriptPubKey(h160)
-    elif s[:3] in ("bc1", "tb1"):
+    elif s[:4] in ("bc1q", "tb1q"):
         if len(s) == 42:
             # p2wpkh
             return P2WPKHScriptPubKey(decode_bech32(s)[2])
         elif len(s) == 62:
             # p2wskh
             return P2WSHScriptPubKey(decode_bech32(s)[2])
+    elif s[:4] in ("bc1p", "tb1p"):
+        if len(s) != 62:
+            raise RuntimeError(f"unknown type of address: {s}")
+        # p2tr
+        return P2TRScriptPubKey(decode_bech32(s)[2])
 
     raise RuntimeError(f"unknown type of address: {s}")
